.. documentation master file, created by
   sphinx-quickstart on Fri Mar 31 11:29:10 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome!
========

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Databases
---------

Supported plant databases.

.. toctree::
   :maxdepth: 2

   de
   nc
   pfaf
   usda-plants

Books
-----

Summary of books on permaculture.

.. toctree::
   :maxdepth: 2

   la-ferme-impossible
   la-revolution-dun-seul-brin-de-paille

Videos
------

Interesting videos on permaculture.

.. toctree::
   :maxdepth: 2

   videos

API Reference
-------------

Documentation on functions, classes and methods.

.. toctree::
   :maxdepth: 3

   modules

Additional Notes
----------------

.. toctree::
   :maxdepth: 2

   contributing
   style_guide
   license
   changes
